summaryrefslogtreecommitdiffstats
path: root/util/fipsdist.pl
diff options
context:
space:
mode:
Diffstat (limited to 'util/fipsdist.pl')
-rw-r--r--util/fipsdist.pl26
1 files changed, 24 insertions, 2 deletions
diff --git a/util/fipsdist.pl b/util/fipsdist.pl
index 20c3999c93..621f90493e 100644
--- a/util/fipsdist.pl
+++ b/util/fipsdist.pl
@@ -21,11 +21,29 @@ foreach (split / /, $ENV{LINKDIRS} ) { $cdirs{$_} = 1 };
$cdirs{perlasm} = 1;
+my %keep =
+ (
+ "Makefile.fips" => 1,
+ "Makefile.shared" => 1,
+ "README.FIPS" => 1,
+ "e_os.h" => 1,
+ "e_os2.h" => 1,
+ "Configure" => 1,
+ "config" => 1,
+ );
+
while (<STDIN>)
{
chomp;
- # Skip directories but leave top level files.
- next unless (/^(fips\/|crypto|util|test|include|ms)/ || (!/\// && -f $_));
+ # Keep top level files in list
+ if (!/\// && -f $_)
+ {
+ next unless exists $keep{$_};
+ }
+ else
+ {
+ next unless (/^(fips\/|crypto|util|test|include|ms)/);
+ }
if (/^crypto\/([^\/]+)/)
{
# Skip unused directories under crypto/
@@ -37,6 +55,10 @@ while (<STDIN>)
next if !/(\w+\.c)$/ || !exists $tarobjs{$1};
}
}
+ if (/^test\//)
+ {
+ next unless /Makefile/ || /dummytest.c/;
+ }
print "$_\n";
}
exit 1;